@@ -1,7 +1,7 @@
 from django.db.models import Min
 from django.http import Http404
-from django.utils.encoding import force_text
-from django.utils.translation import ugettext as _
+from django.utils.encoding import force_str
+from django.utils.translation import gettext as _
 from django.views.generic import DetailView, ListView, YearArchiveView
 from django.views.generic.detail import SingleObjectMixin
 
@@ -134,8 +134,8 @@ class ReadingYearArchiveView(YearArchiveView):
         objects = context["object_list"]
         if len(objects) > 1:
             if (
-                objects.first().end_granularity == Reading.DATE_GRANULARITY_YEAR
-                and objects.last().end_granularity == Reading.DATE_GRANULARITY_YEAR
+                objects.first().end_granularity == Reading.DateGranularity.YEAR
+                and objects.last().end_granularity == Reading.DateGranularity.YEAR
             ):
                 # If the first and last publications only have year-based
                 # granularity, assume everything does, so we shouldn't
@@ -167,7 +167,7 @@ class ReadingYearArchiveView(YearArchiveView):
                 raise Http404(
                     _("No %(verbose_name_plural)s available")
                     % {
-                        "verbose_name_plural": force_text(
+                        "verbose_name_plural": force_str(
                             qs.model._meta.verbose_name_plural
                         )
                     }
